@@ -103,6 +103,11 @@ void kpMainWindow::setupFileMenuActions ()
     d->actionExport = ac->addAction(QStringLiteral("file_export"));
     d->actionExport->setText (i18n ("E&xport..."));
     d->actionExport->setIcon(QIcon::fromTheme(QStringLiteral("document-export")));
+    d->actionExport->setToolTip(i18nc("@info:tooltip", "Export to another file"));
+    d->actionExport->setWhatsThis(xi18nc("@info:whatsthis",
+                                         "This saves the document with a different name, similar to <interface>Save As</interface>, "
+                                         "but the current document is not changed.<nl/>"
+                                         "This way you can keep the last-used save folder independent from the folder of the current document."));
     connect (d->actionExport, &QAction::triggered, this, &kpMainWindow::slotExport);
 
     d->actionScan = ac->addAction(QStringLiteral("file_scan"));
@@ -887,7 +892,11 @@ QUrl kpMainWindow::askForSaveURL (const QString &caption,
     fd.setCustomWidget (saveOptionsWidget);
     KFileWidget *fw = fd.fileWidget();
     fw->setConfirmOverwrite (true);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     fw->setMimeFilter (mimeTypes, fdSaveOptions.mimeType ());
+#else
+    fw->setFilters (KFileFilter::fromMimeTypes(mimeTypes), KFileFilter::fromMimeType(fdSaveOptions.mimeType ()));
+#endif
     if (localOnly) {
         fw->setMode (KFile::File | KFile::LocalOnly);
     }
@@ -895,7 +904,13 @@ QUrl kpMainWindow::askForSaveURL (const QString &caption,
     saveOptionsWidget->setVisualParent (&fd);
 
     connect (fw, &KFileWidget::filterChanged,
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
              saveOptionsWidget, &kpDocumentSaveOptionsWidget::setMimeType);
+#else
+             saveOptionsWidget, [saveOptionsWidget](const KFileFilter &filter) {
+                 saveOptionsWidget->setMimeType(filter.mimePatterns().first());
+            });
+#endif
 
     if ( fd.exec() == QDialog::Accepted )
     {
